FfiHelper class

A helper class that encapsulates a DynamicLibrary and provides a convenient API for using the library.

Properties

allocator → Allocator
Default allocator for this library
no setter
hashCode → int
The hash code for this object.
no setterinherited
library → DynamicLibrary
The underlying DynamicLibrary instance.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeUsing<R>(R computation(Arena), [Allocator? allocator]) → R
Safely runs the provided computation function within an Arena, ensuring that all allocations are released upon completion.
safeWithZoneArena<R>(R computation(), [Allocator? allocator]) → R
Safely runs the provided computation function within a zoned Arena, ensuring that all allocations are released upon completion.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load(String modulePath, {Set<LoadOption> options = const {}, Map<AppType, String> overrides = const {}}) → Future<FfiHelper>
Loads a dynamic library from the specified modulePath and returns an FfiHelper instance encapsulating the library.